from chardet.universaldetector import UniversalDetector


def guess_encoding(path):
    """guess the encoding of a file at a given path"""
    detector = UniversalDetector()
    with open(path, "rb") as fh:
        for line in fh:
            detector.feed(line)
            if detector.done:
                break
    detector.close()
    return detector.result["encoding"]


def extract_wiki_definitions(file_handle):
    """extract the wiki definitions from a moinmoin farmconfig file"""
    for line in file_handle:
        if line.startswith("wikis = ["):
            break
    for line in file_handle:
        if line.startswith("]"):
            break
        parts = split_wiki_definitions(line)
        if parts is not None:
            yield parts[1], parts[3]


def split_wiki_definitions(line):
    """small helper, returns the wiki name and wiki url regex"""
    for quote in ('"', "'"):
        parts = line.split(quote)
        if len(parts) == 5:
            return parts
        return None


def extract_data_dir(fh):
    """returns the data directory from a single moinmoin wiki config"""
    for line in fh:
        parts = line.split("=", 1)
        if len(parts) == 2:
            name, value = parts
            if name.strip() == "data_dir":
                value = value.strip()
                return value[1:-1]
